import * as log from './log'
import * as events from 'events'

export type ChainItemFunc = (message: any) => any

export interface Receivable {
    begin() : void;
    send(message : any) : void;
}

class LastChainItem implements Receivable {
    public begin() : void {
    }

    public send(message: any) {
        log.info(`Last chain item, final result ${JSON.stringify(message)}`)
    }
}

let lastChainItem : LastChainItem = new LastChainItem();

export abstract class AChainItem extends events.EventEmitter implements Receivable {
    protected label : string
    protected next : Receivable


    constructor(label : string) {
        super()
        this.label = label
        this.next = lastChainItem
    }

    public toString() : string {
        return `<${this.label}>`
    }

    public registerNext(next : AChainItem) :void {
        this.next = next
    }

    public send(message : any) : void {
        this.emit('yourturn', message)
    }

    public abstract begin() : void
}

export abstract class AAsyncBaseChainItem extends AChainItem  {
    constructor(label : string) {
        super(label)
    }

    protected abstract func(message : any, finished : (message : any) => void) : void;

    public begin() :void {
        if (this.next != null) {
            this.next.begin()
        }
        this.addListener('yourturn', (message : any) : void => {
            log.info(`Calling ${this.toString()}`)
            this.func(message, this.next.send)
        })
    }
}

export abstract class ABaseChainItem extends AChainItem  {
    constructor(label : string) {
        super(label)
    }

    protected abstract func(message : any) : any;

    public begin() :void {
        if (this.next != null) {
            this.next.begin()
        }
        this.addListener('yourturn', (message : any) : void => {
            log.info(`Calling ${this.toString()}`)
            let result : any = this.func(message)
            this.next.send(result)
        })
    }
}

export class ChainItem extends ABaseChainItem  {
    private chainItemFunc : ChainItemFunc

    public toString() : string {
        let funcName : string = (this.chainItemFunc.name === "") ? "lambda" : this.chainItemFunc.name
        return `<${funcName}, ${this.label}>`
    }

    public registerFunc(func : ChainItemFunc) : void {
        this.chainItemFunc = func
    }

    protected func(message : any) : any {
        return this.chainItemFunc(message)
    }
}

