import * as log from './log'
import * as utils from './utils'

export class EspThermData {
    private temperature : number
    private voltage : number
    private timeConsumed : number

    constructor(temperature:number, voltage:number, timeConsumed:number) {
        this.temperature = temperature
        this.voltage = voltage
        this.timeConsumed = timeConsumed
    }

    toString() :string {
        return JSON.stringify(this)
    }

    toJSON() : any {
        return utils.jsonPrepaper(this, [])
    }
}

export class EspThermMetadata {
    private client : string
    private timestamp : Date

    constructor(client : string, timestamp? : Date) {
        this.client = client
        this.timestamp = (timestamp) ? timestamp : new Date()
    }

    toString() :string {
        return JSON.stringify(this)
    }

    toJSON() : any {
        return utils.jsonPrepaper(this, [])
    }
}

export class EspThermMessage {
    private data : EspThermData
    private metadata : EspThermMetadata


    constructor(client:string, temperature:number, voltage:number, timeConsumed:number) {
        this.data = new EspThermData(temperature, voltage, timeConsumed)
        this.metadata = new EspThermMetadata(client)
    }

    toString() :string {
        return JSON.stringify(this)
    }

    toJSON() : any {
        return utils.jsonPrepaper(this, [])
    }
}

export function espThermToJson(message : any) : any {
    let messageStr : string = "" + <string>message
    let parts : string[] = messageStr.split(' ')
    let espThermMessage : EspThermMessage = new EspThermMessage(parts[0], 
        parseFloat(parts[1]), parseFloat(parts[2]), 
        parseInt(parts[3]))
    return espThermMessage
}