import * as chalk from 'chalk'
import * as moment from 'moment'

enum Level {
    All,
    NoDebug,
    NoDebugNoInfo,
    NoDebugNoInfoNoWarning
}

var level = Level.NoDebug

function timestamp(): string {
    return moment().format('HH:mm:ss.SSS')
}

export function setLevel(value: string): void {
    switch (value) {
        case 'info':  level = Level.NoDebug; break
        case 'warn':  level = Level.NoDebugNoInfo; break
        case 'error': level = Level.NoDebugNoInfoNoWarning; break
        default:      level = Level.All
    }
}

export function info(message: string): void {
    if (level < Level.NoDebugNoInfo) {
        console.log(`${timestamp()} ${chalk.bold.cyan('[ II ]')} ${message}`)
    }
}

export function warn(message: string): void {
    if (level < Level.NoDebugNoInfoNoWarning) {
        console.log(`${timestamp()} ${chalk.bold.yellow('[ WW ]')} ${message}`)
    }
}

export function error(message: string): void {
    console.log(`${timestamp()} ${chalk.bold.red('[ EE ]')} ${message}`)
}

export function success(message: string): void {
    console.log(`${timestamp()} ${chalk.bold.green('[ OK ]')} ${message}`)
}

export function debug(message: string): void {
    if (level < Level.NoDebug) {
        console.log(`${timestamp()} ${chalk.bold.magenta('[ DB ]')} ${message}`)
    }
}
