import * as log from './log'
import * as mqtt from './mqttdispatcher'
import * as callchain from './callchain'
import * as fs from 'fs'
import * as cmdargs from 'command-line-args'

import * as EspThermToJson from './espthermtojson'
import * as MongoSave from './mongosave'

log.info("Dispatcher starting")

const optionDefinitions = [
    { name: 'verbose', alias: 'v', type: Boolean },
    { name: 'config', alias: 'c', type: String, defaultValue: '~/mqttDispatcher.conf' }
];
const OPTIONS = cmdargs(optionDefinitions)
const CONFIG = JSON.parse(fs.readFileSync(OPTIONS.config, "utf8"))

let dispatcher = new mqtt.MqttDispatcher(CONFIG.brokerUrl, 
    CONFIG.brokerUser, CONFIG.brokerPass, CONFIG.brokerCa)

dispatcher.register('IoT/espThermometer2/#', 'toJson', EspThermToJson.espThermToJson)

let mongo : MongoSave.MongoSave = new MongoSave.MongoSave(CONFIG.mongoDbUrl)
dispatcher.register('IoT/espThermometer2/#', 'MongoSave', mongo);


dispatcher.exec()
log.info("Dispatcher running")






