import * as CallChain from './callchain'
import * as log from './log'
import * as MongoDB from 'mongodb'


export interface MongoItem {
    id : MongoDB.ObjectID
    payload : any
}

export class MongoSave extends CallChain.AAsyncBaseChainItem  {
    private url : string
    private mongoClient : MongoDB.MongoClient
    private dbh : MongoDB.Db | undefined
    private connectPending : boolean

    constructor(url:string) {
        super('MongoSave')
        this.url = url
        this.mongoClient = new MongoDB.MongoClient()
        this.connectPending = false
    }

    protected func(message : any, finished : (message : any) => void) : void {
        if (! this.dbh) {
            log.info("Not database connection yet")
            if (! this.connectPending) {
                this.connectPending = true
                this.mongoClient.connect(this.url)
                    .then((db:MongoDB.Db) => { 
                        log.info("Successfully opened MongoDB connect")
                        this.dbh = db
                    })
                    .catch((err) => {
                        log.error(`Failure when opening MongoDB connect: ${err}`)
                        this.dbh = undefined
                    })
            } else {
                log.info("Connecting to database is pending")
            }
        }
        if (this.dbh) {
            log.info("Database handle is available")
            let coll : MongoDB.Collection = this.dbh.collection("iot")
            coll.insertOne(message)
                .then((res : MongoDB.InsertOneWriteOpResult) => {
                    log.info(`Successfully wrote one item in database: ${res.insertedId}`)
                    let nextValue = <MongoItem>{id: res.insertedId, payload: message}
                    finished(nextValue)
                })
                .catch((err : any) => {
                    log.error(`Failure when trying to write one item in database: ${err}`)
                    log.error("Chain interrupted")
                })
        } else {
            log.error(`No database connection yet, drop message ${message}`)
            log.error("Chain interrupted")
        }
        log.info(`Returning from ${this.label}`)
    }

    /*
    public begin() :void {
        if (this._next != null) {
            this._next.begin()
        }
        this.addListener('yourturn', (message : any) : void => {
            log.info(`Calling ${this.toString()}`)
            let result : any = this.func(message)
            if (this._next == null) {
                log.info(`Last chain item, final result ${result}`)
            } else {
                this._next.send(result)
            }
        })
    }
    */

}
